@@ -25,12 +25,14 @@ int main(int argc, char *argv[])
 #if  defined(Q_WS_MAEMO_5)
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&clock);
     adaptor->setSettingsAvailable(true);
+    QString aId = adaptor->getAppletId();
+    clock.setId(aId);
     QObject::connect(adaptor, SIGNAL(settingsRequested()), &clock, SLOT(showSettingsDialog()));
     QObject::connect(adaptor, SIGNAL(homescreenChanged(bool)), &clock, SLOT(homeScreenChanged(bool)));
-    clock.setLineWidth(0);
-    clock.show();
-#else
+//    clock.setLineWidth(0);
     clock.show();
+//#else
+  //  clock.show();
 #endif
     return app.exec();
 }
